spoon.serialprop

Package spoon :: Class serialprop |
[hide private]
[frames] | no frames]

# Class serialprop

source code

    object --+
             |
            serialprop

When used like a property in a Serial class, it will act as a flag to the serializer that only properties that are of type `serialprop` or `lazyprop` are to be serialized.

Any subclass of this will be treated the same way, so if you need your property to behave like a customizable property, then subclass away.

Instance Methods | [hide private]
`` | __del__(self, obj)
`` | __get__(self, obj, Type=None)
`` | __init__(self, value=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __set__(self, obj, value)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __del__(self, obj) (Destructor) | source code
None

### __get__(self, obj, Type=None) | source code
None

### __init__(self, value=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __set__(self, obj, value) | source code
None